@@ -16,15 +16,20 @@ Implementation Notes
 
 **Hardware:**
 
- * Adafruit LC709023 Breakout: https://www.adafruit.com/product/4712
+* `Adafruit LC709203F LiPoly / LiIon Fuel Gauge and Battery Monitor
+  <https://www.adafruit.com/product/4712>`_ (Product ID: 4712)
 
 **Software and Dependencies:**
 
 * Adafruit CircuitPython firmware for the supported boards:
-  https://github.com/adafruit/circuitpython/releases
+  https://circuitpython.org/downloads
+
+* Adafruit's Bus Device library:
+  https://github.com/adafruit/Adafruit_CircuitPython_BusDevice
+
+* Adafruit's Register library:
+  https://github.com/adafruit/Adafruit_CircuitPython_Register
 
-# * Adafruit's Bus Device library: https://github.com/adafruit/Adafruit_CircuitPython_BusDevice
-# * Adafruit's Register library: https://github.com/adafruit/Adafruit_CircuitPython_Register
 """
 
 from micropython import const
@@ -41,6 +46,9 @@ LC709203F_CMD_APA = const(0x0B)
 LC709203F_CMD_INITRSOC = const(0x07)
 LC709203F_CMD_CELLVOLTAGE = const(0x09)
 LC709203F_CMD_CELLITE = const(0x0F)
+LC709203F_CMD_CELLTEMPERATURE = const(0x08)
+LC709203F_CMD_THERMISTORB = const(0x06)
+LC709203F_CMD_STATUSBIT = const(0x16)
 
 
 class CV:
@@ -97,7 +105,12 @@ PackSize.add_values(
 
 
 class LC709203F:
-    """Interface library for LC709203F battery monitoring and fuel gauge sensors"""
+    """Interface library for LC709203F battery monitoring and fuel gauge sensors
+
+    :param ~busio.I2C i2c_bus: The I2C bus the device is connected to
+    :param int address: The I2C device address. Defaults to :const:`0x0B`
+
+    """
 
     def __init__(self, i2c_bus, address=LC709203F_I2CADDR_DEFAULT):
         self.i2c_device = i2c_device.I2CDevice(i2c_bus, address)
@@ -121,6 +134,18 @@ class LC709203F:
         """Returns percentage of cell capacity"""
         return self._read_word(LC709203F_CMD_CELLITE) / 10
 
+    @property
+    def cell_temperature(self):
+        """Returns the temperature of the cell"""
+        return self._read_word(LC709203F_CMD_CELLTEMPERATURE) / 10 - 273.15
+
+    @cell_temperature.setter
+    def cell_temperature(self, value):
+        """Sets the temperature in the LC709203F"""
+        if self.thermistor_enable:
+            raise AttributeError("temperature can only be set in i2c mode")
+        self._write_word(LC709203F_CMD_CELLTEMPERATURE, int(value + 273.15) * 10)
+
     @property
     def ic_version(self):
         """Returns read-only chip version"""
@@ -159,6 +184,28 @@ class LC709203F:
             raise AttributeError("pack_size must be a PackSize")
         self._write_word(LC709203F_CMD_APA, size)
 
+    @property
+    def thermistor_bconstant(self):
+        """Returns the thermistor B-constant"""
+        return self._read_word(LC709203F_CMD_THERMISTORB)
+
+    @thermistor_bconstant.setter
+    def thermistor_bconstant(self, bconstant):
+        """Sets the thermistor B-constant"""
+        self._write_word(LC709203F_CMD_THERMISTORB, bconstant)
+
+    @property
+    def thermistor_enable(self):
+        """Returns the current temperature source"""
+        return self._read_word(LC709203F_CMD_STATUSBIT)
+
+    @thermistor_enable.setter
+    def thermistor_enable(self, status):
+        """Sets the temperature source to Tsense"""
+        if not status in (True, False):
+            raise AttributeError("thermistor_enable must be True or False")
+        self._write_word(LC709203F_CMD_STATUSBIT, status)
+
     # pylint: disable=no-self-use
     def _generate_crc(self, data):
         """8-bit CRC algorithm for checking data"""
@@ -171,7 +218,8 @@ class LC709203F:
                     crc = (crc << 1) ^ 0x07
                 else:
                     crc <<= 1
-        return crc & 0xFF
+                crc &= 0xFF
+        return crc
 
     def _read_word(self, command):
         self._buf[0] = LC709203F_I2CADDR_DEFAULT * 2  # write byte
